Download the image of an athlete from the FIS page. Images are not available for all athletes.
Arguments
- athlete
a list or data frame with the field/column
competitor_idthat describe a single athlete. The easiest way to create such a data frame is through the functionsquery_athletes(),query_race(), orquery_standings(). These functions can return multiple athletes, butget_athlete_image()only downloads the image for one athlete. If multiple athletes are passed, only the first one will be used.- file
if given, the image file will be stored to the given path. The image files are png or jpg and the file ending will be added automatically depending on the file type. Any user provided file ending will be ignored.